@@ -246,6 +246,9 @@ def getInterfaces():
             return False
         if device.sysfs.exists(x, "bonding_slave"):
             return False
+        # exclude slave devices
+        if any(device.sysfs.glob(x, "lower_*")):
+            return False
         return True
 
     return sorted(path.basename(x)
@@ -253,6 +256,11 @@ def getInterfaces():
                     device.sysfs.Path.ClassNet, fullpath=True)
                   if filter_ethernet(x))
 
+def getMaster(iface):
+    master_path = [device.sysfs.Path.ClassNet, iface, "master"]
+    if device.sysfs.exists(*master_path):
+        return path.split(device.sysfs.realpath(*master_path))[-1]
+    return None
 
 def getIp(iface):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
